@@ -163,6 +163,8 @@ class SaratogaResource(Resource):
 
             # Read in the content from the request
             requestContent = request.content.read()
+            # Set it back to the start
+            request.content.seek(0)
 
             try:
                 # Parse it from JSON
